<?php

namespace Litecms\Teammember\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Teammember\Models\Teammembers;

class TeammembersPolicy
{

    /**
     * Determine if the given user can view the teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function view(UserPolicy $user, Teammembers $teammembers)
    {
        if ($user->canDo('teammember.teammembers.view') && $user->isAdmin()) {
            return true;
        }

        return $teammembers->user_id == user_id() && $teammembers->user_type == user_type();
    }

    /**
     * Determine if the given user can create a teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('teammember.teammembers.create');
    }

    /**
     * Determine if the given user can update the given teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function update(UserPolicy $user, Teammembers $teammembers)
    {
        if ($user->canDo('teammember.teammembers.edit') && $user->isAdmin()) {
            return true;
        }

        return $teammembers->user_id == user_id() && $teammembers->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Teammembers $teammembers)
    {
        return $teammembers->user_id == user_id() && $teammembers->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Teammembers $teammembers)
    {
        if ($user->canDo('teammember.teammembers.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given teammembers.
     *
     * @param UserPolicy $user
     * @param Teammembers $teammembers
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Teammembers $teammembers)
    {
        if ($user->canDo('teammember.teammembers.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
